<?php

namespace Drupal\standwithukraine;

/**
 * Provides a class for message settings.
 */
class StandWithUkraineSettings implements StandWithUkraineSettingsInterface {

  /**
   * Display the message's text as a single line.
   *
   * @var bool
   */
  protected $single;

  /**
   * The page side where a message should be displayed.
   *
   * @var string
   */
  protected $position;

  /**
   * The message offset.
   *
   * @var int
   */
  protected $offset;

  /**
   * Constructs a new StandWithUkraineSettings.
   *
   * @param bool $single
   *   (optional) Display the message's text as a single line. Defaults to
   *   FALSE.
   * @param string $position
   *   (optional) The page side where a message should be displayed. Defaults to
   *   StandWithUkraineSettingsInterface::POSITION_TOP.
   * @param int $offset
   *   (optional) The message offset. Defaults to 0.
   */
  public function __construct(
    $single = FALSE,
    $position = self::POSITION_TOP,
    $offset = 0
  ) {
    $this->single = $single;
    $this->position = $position;
    $this->offset = $offset;
  }

  /**
   * {@inheritdoc}
   */
  public function isSingle() {
    return $this->single;
  }

  /**
   * {@inheritdoc}
   */
  public function setDouble() {
    $this->single = FALSE;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPosition() {
    return $this->position;
  }

  /**
   * {@inheritdoc}
   */
  public function setPosition($position) {
    $this->position = $position;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOffset() {
    return $this->offset;
  }

  /**
   * {@inheritdoc}
   */
  public function setOffset($offset) {
    $this->offset = $offset;

    return $this;
  }

}
