<?php

namespace Drupal\standwithukraine;

/**
 * Defines an interface for class for message settings.
 */
interface StandWithUkraineSettingsInterface {

  /**
   * Sticky a message to the left side of the page.
   */
  const POSITION_LEFT = 'left';

  /**
   * Sticky a message to the top side of the page.
   */
  const POSITION_TOP = '';

  /**
   * Sticky a message to the right side of the page.
   */
  const POSITION_RIGHT = 'right';

  /**
   * Check if the message's text should be displayed in a single line.
   *
   * @return bool
   *   TRUE, if so.
   */
  public function isSingle();

  /**
   * Display message in view mode of two lines.
   *
   * @return self
   *   The settings object.
   */
  public function setDouble();

  /**
   * Returns the page side where a message should be displayed.
   */
  public function getPosition();

  /**
   * Defines the page side where a message should be displayed.
   *
   * @param string $position
   *   The position type.
   *
   * @return self
   *   The settings object.
   */
  public function setPosition($position);

  /**
   * Returns message offset.
   *
   * @return int
   *   The number of pixels.
   */
  public function getOffset();

  /**
   * Defines message offset.
   *
   * @param int $offset
   *   The number of pixels.
   *
   * @return self
   *   The settings object.
   */
  public function setOffset($offset);

}
