<?php

namespace Drupal\standwithukraine;

use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Trait StandWithUkraineTrait.
 *
 * @package Drupal\standwithukraine
 */
trait StandWithUkraineTrait {

  /**
   * The suggested websites list.
   */
  protected $urls = [
    'https://supportukrainenow.org',
    'https://war.ukraine.ua/',
  ];

  /**
   * Add link field to form.
   *
   * @param array $form
   *   The extendable form.
   * @param array $values
   *   The default values.
   */
  public function alter(array &$form, array $values) {
    $form['single'] = [
      '#type' => 'radios',
      '#title' => $this->t('Lines number'),
      '#description' => $this->t('Define if the message\'s text should be split
or displayed as a single row.'),
      '#options' => [
        1 => $this->t('One'),
        0 => $this->t('Two'),
      ],
      '#default_value' => (int) ($values['single'] ?? 0),
    ];

    $form['url'] = [
      '#type' => 'url',
      '#title' => $this->t('Link'),
      '#description' => sprintf(
        '%s %s.',
        $this->t('For example:'),
        implode(
          ', ',
          array_map(
            function ($url) {
              return Link::fromTextAndUrl(
                parse_url($url, PHP_URL_HOST),
                Url::fromUri($url, ['target' => '_blank'])
              )->toString();
            },
            $this->urls
          )
        )
      ),
      '#default_value' => $values['url'],
    ];
  }

}
